==> va108xx-0.1.0.crate: va108xx-0.1.0/src/tim0/cascade0.rs <==
#[doc = "Register `CASCADE0` reader"]
pub struct R(crate::R<CASCADE0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CASCADE0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CASCADE0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CASCADE0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CASCADE0` writer"]
pub struct W(crate::W<CASCADE0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CASCADE0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CASCADE0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CASCADE0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CASSEL` reader - Cascade Selection"]
pub struct CASSEL_R(crate::FieldReader<u8, u8>);
impl CASSEL_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        CASSEL_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CASSEL_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CASSEL` writer - Cascade Selection"]
pub struct CASSEL_W<'a> {
    w: &'a mut W,
}
impl<'a> CASSEL_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:7 - Cascade Selection"]
    #[inline(always)]
    pub fn cassel(&self) -> CASSEL_R {
        CASSEL_R::new(self.bits as u8)
    }
}
impl W {
    #[doc = "Bits 0:7 - Cascade Selection"]
    #[inline(always)]
    pub fn cassel(&mut self) -> CASSEL_W {
        CASSEL_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Cascade Enable Selection\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cascade0](index.html) module"]
pub struct CASCADE0_SPEC;
impl crate::RegisterSpec for CASCADE0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [cascade0::R](R) reader structure"]
impl crate::Readable for CASCADE0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [cascade0::W](W) writer structure"]
impl crate::Writable for CASCADE0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CASCADE0 to value 0"]
impl crate::Resettable for CASCADE0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> va108xx-0.2.3.crate: va108xx-0.2.3/src/tim0/cascade0.rs <==
#[doc = "Register `CASCADE0` reader"]
pub struct R(crate::R<CASCADE0_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CASCADE0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CASCADE0_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CASCADE0_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CASCADE0` writer"]
pub struct W(crate::W<CASCADE0_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CASCADE0_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CASCADE0_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CASCADE0_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CASSEL` reader - Cascade Selection"]
pub struct CASSEL_R(crate::FieldReader<u8, u8>);
impl CASSEL_R {
    #[inline(always)]
    pub(crate) fn new(bits: u8) -> Self {
        CASSEL_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CASSEL_R {
    type Target = crate::FieldReader<u8, u8>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CASSEL` writer - Cascade Selection"]
pub struct CASSEL_W<'a> {
    w: &'a mut W,
}
impl<'a> CASSEL_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:7 - Cascade Selection"]
    #[inline(always)]
    pub fn cassel(&self) -> CASSEL_R {
        CASSEL_R::new((self.bits & 0xff) as u8)
    }
}
impl W {
    #[doc = "Bits 0:7 - Cascade Selection"]
    #[inline(always)]
    pub fn cassel(&mut self) -> CASSEL_W {
        CASSEL_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Cascade Enable Selection\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cascade0](index.html) module"]
pub struct CASCADE0_SPEC;
impl crate::RegisterSpec for CASCADE0_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [cascade0::R](R) reader structure"]
impl crate::Readable for CASCADE0_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [cascade0::W](W) writer structure"]
impl crate::Writable for CASCADE0_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CASCADE0 to value 0"]
impl crate::Resettable for CASCADE0_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
